==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebPinColumnEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebPinColumnEventArgsDetailDescription } from "./WebPinColumnEventArgsDetailDescription";
/**
 * @hidden
 */
var WebPinColumnEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebPinColumnEventArgsDetailDescriptionMetadata, _super);
    function WebPinColumnEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPinColumnEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebPinColumnEventArgsDetailDescriptionMetadata.a == null) {
            WebPinColumnEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPinColumnEventArgsDetailDescriptionMetadata.c(WebPinColumnEventArgsDetailDescriptionMetadata.a);
        }
        if (a.j(WebPinColumnEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.y(WebPinColumnEventArgsDetailDescriptionMetadata.a);
        WebColumnDescriptionMetadata.d(a);
    };
    WebPinColumnEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:PinColumnEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Column", "ExportedType:WebColumn");
        a.item("InsertAtIndex", "Number:double");
        a.item("IsPinned", "Boolean");
    };
    WebPinColumnEventArgsDetailDescriptionMetadata.d = function (a) {
        WebPinColumnEventArgsDetailDescriptionMetadata.b(a);
        a.aa("WebPinColumnEventArgsDetail", function () { return new WebPinColumnEventArgsDetailDescription(); });
        a.z("WebPinColumnEventArgsDetail", WebPinColumnEventArgsDetailDescriptionMetadata.a);
    };
    WebPinColumnEventArgsDetailDescriptionMetadata.$t = markType(WebPinColumnEventArgsDetailDescriptionMetadata, 'WebPinColumnEventArgsDetailDescriptionMetadata');
    WebPinColumnEventArgsDetailDescriptionMetadata.a = null;
    return WebPinColumnEventArgsDetailDescriptionMetadata;
}(Base));
export { WebPinColumnEventArgsDetailDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebPinColumnEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebPinColumnEventArgsDetailDescription } from "./WebPinColumnEventArgsDetailDescription";
/**
 * @hidden
 */
var WebPinColumnEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebPinColumnEventArgsDetailDescriptionMetadata, _super);
    function WebPinColumnEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPinColumnEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebPinColumnEventArgsDetailDescriptionMetadata.a == null) {
            WebPinColumnEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPinColumnEventArgsDetailDescriptionMetadata.c(WebPinColumnEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebPinColumnEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebPinColumnEventArgsDetailDescriptionMetadata.a);
        WebColumnDescriptionMetadata.d(a);
    };
    WebPinColumnEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:PinColumnEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Column", "ExportedType:WebColumn");
        a.item("InsertAtIndex", "Number:double");
        a.item("IsPinned", "Boolean");
    };
    WebPinColumnEventArgsDetailDescriptionMetadata.d = function (a) {
        WebPinColumnEventArgsDetailDescriptionMetadata.b(a);
        a.ac("WebPinColumnEventArgsDetail", function () { return new WebPinColumnEventArgsDetailDescription(); });
        a.ab("WebPinColumnEventArgsDetail", WebPinColumnEventArgsDetailDescriptionMetadata.a);
    };
    WebPinColumnEventArgsDetailDescriptionMetadata.$t = markType(WebPinColumnEventArgsDetailDescriptionMetadata, 'WebPinColumnEventArgsDetailDescriptionMetadata');
    WebPinColumnEventArgsDetailDescriptionMetadata.a = null;
    return WebPinColumnEventArgsDetailDescriptionMetadata;
}(Base));
export { WebPinColumnEventArgsDetailDescriptionMetadata };
